package com.example.client;

import java.util.Date;

import com.example.client.resources.Resources;
import com.example.client.resources.TextBundle;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.logical.shared.SelectionHandler;
import com.google.gwt.event.logical.shared.ValueChangeEvent;
import com.google.gwt.event.logical.shared.ValueChangeHandler;
import com.sencha.gxt.core.client.util.Format;
import com.sencha.gxt.widget.core.client.info.Info;
import com.sencha.gxt.widget.core.client.menu.Item;
import com.sencha.gxt.widget.core.client.menu.Menu;
import com.sencha.gxt.widget.core.client.menu.DateMenu;
import com.sencha.gxt.widget.core.client.menu.MenuItem;
import com.sencha.gxt.widget.core.client.menu.ColorMenu;
import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
import com.sencha.gxt.widget.core.client.button.TextButton;
import com.sencha.gxt.widget.core.client.menu.CheckMenuItem;
import com.sencha.gxt.widget.core.client.button.SplitButton;
import com.sencha.gxt.widget.core.client.button.ToggleButton;
import com.sencha.gxt.widget.core.client.toolbar.FillToolItem;
import com.sencha.gxt.widget.core.client.menu.SeparatorMenuItem;
import com.sencha.gxt.widget.core.client.toolbar.SeparatorToolItem;
import com.google.gwt.i18n.client.DateTimeFormat;
import com.google.gwt.i18n.client.DateTimeFormat.PredefinedFormat;

public class GXTToolbar
{
	private  ToolBar          toolBar    = null;
	
	private  Menu             menu       = null;
	
	private  TextBundle       TEXT       = null;
	
//	private  TextButton       scrollerButton = null;
	private final String TEMPLATE = "<span style=\"font-size:16px;font-family:'Times New Roman',Tahoma,Georgia;\">{0}</span>"; 
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public GXTToolbar(final int height, SelectionHandler<Item> handler)
	{
		TEXT = GWT.create(TextBundle.class);
		createMainMenu(handler);
		createToolBar(handler);
		toolBar.setHeight(height);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	public ToolBar getToolBar()
	{
		return this.toolBar;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createMainMenu(SelectionHandler<Item> handler)
	{
		menu = new Menu();
		menu.addSelectionHandler(handler);
		menu.add(new SeparatorMenuItem());

		createCheckMenuItems(menu);		
	   
		menu.add(new SeparatorMenuItem());
	   
		createRadioMenu(menu, handler);
		createDateMenu (menu);
		createColorMenu(menu);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createToolBar(SelectionHandler<Item> handler)
	{
		toolBar = new ToolBar();
		toolBar.setEnabled(true);
		
		TextButton item1 = new TextButton(TEXT.menu_button());
		item1.setIcon(Resources.IMAGES.menu_show());
		item1.setHTML(Format.substitute(TEMPLATE, TEXT.menu_button()));

		item1.setMenu(menu);
		
		toolBar.add(item1);
	   
		toolBar.add(new SeparatorToolItem());
	   
		SplitButton splitItem = new SplitButton("Split Button");
		splitItem.setIcon(Resources.IMAGES.list_items());
		splitItem.setHTML(Format.substitute(TEMPLATE, "Split Button"));
		
		splitItem.setMenu(createSplitMenu (handler));

		toolBar.add(splitItem);
	   
		toolBar.add(new SeparatorToolItem());

		ToggleButton toggle = new ToggleButton("Toggle");
		toggle.setHTML(Format.substitute(TEMPLATE, "Toggle button"));
		toggle.setValue(true);
		toolBar.add(toggle);
	   
		toolBar.add(new SeparatorToolItem());
	   
		TextButton scrollerButton = new TextButton("Scrolling Menu");
		   
		createScrollerMenu(scrollerButton, handler);
		toolBar.add(scrollerButton);
	   
		toolBar.add(new SeparatorToolItem());
		toolBar.add(new FillToolItem());
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private Menu createSplitMenu (SelectionHandler<Item> handler)
	{
		Menu menu = new Menu();
		menu.addSelectionHandler(handler);

		MenuItem item = new MenuItem();
		item.setHTML("<b>Bold</b>");
		menu.add(item);
	   
		item = new MenuItem();
		item.setHTML("<i>Italic</i>");
		menu.add(item);
	   
		item = new MenuItem();
		item.setHTML("<u>Underline</u>");
		menu.add(item);
		
		return menu;
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createRadioMenu(Menu menu, 
			                     SelectionHandler<Item> handler){
		MenuItem radios = new MenuItem("Radio options");
		menu.add(radios);
	   
		Menu radioMenu = new Menu();
		radioMenu.addSelectionHandler(handler);
	   
		CheckMenuItem cmi = new CheckMenuItem("Супермаркет");
		cmi.setGroup("radios");
		cmi.setChecked(true);
		radioMenu.add(cmi);
	   
		cmi = new CheckMenuItem("Гипермаркет");
		cmi.setGroup("radios");
		radioMenu.add(cmi);
		
		radios.setSubMenu(radioMenu);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private String formatDate(Date date)
	{
		DateTimeFormat dtf;
		dtf = DateTimeFormat.getFormat(PredefinedFormat.DATE_SHORT);
		return dtf.format(date);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createDateMenu(Menu menu)
	{
		MenuItem date = new MenuItem("Choose a Date");
		date.setIcon(Resources.IMAGES.calendar());
		menu.add(date);
		final DateMenu dateMenu = new DateMenu();
		dateMenu.getDatePicker().addValueChangeHandler(
				                 new ValueChangeHandler<Date>(){
			@Override
			public void onValueChange(ValueChangeEvent<Date> event) {
				Date date = event.getValue();
				Info.display("Дата изменена", 
						     "Вы выбрали " + formatDate(date));
				dateMenu.hide(true);
			}
		});
		date.setSubMenu(dateMenu);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createColorMenu(Menu menu)
	{
		MenuItem color = new MenuItem("Choose a Color");
		menu.add(color);
		final ColorMenu colorMenu = new ColorMenu();
		colorMenu.getPalette().addValueChangeHandler(
				         new ValueChangeHandler<String>() {
			@Override
	        public void onValueChange(ValueChangeEvent<String> event) {
				String color = event.getValue();
				Info.display("Цвет изменен", "Вы выбрали " + color);
				colorMenu.hide(true);
			}
		});	   
		color.setSubMenu(colorMenu);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createScrollerMenu(TextButton scrollerButton, 
			                        SelectionHandler<Item> handler)
	{
		Menu scrollMenu = new Menu();
		scrollMenu.addSelectionHandler(handler);
		scrollMenu.setMaxHeight(200);
		for (int i = 0; i < 40; i++)
			scrollMenu.add(new MenuItem("Item " + i));
	   
		scrollerButton.setMenu(scrollMenu);
	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	private void createCheckMenuItems(Menu menu)
	{
		CheckMenuItem menuItem = new CheckMenuItem(TEXT.on_select());
		menuItem.setChecked(true);
		menu.add(menuItem);
	   
		menuItem = new CheckMenuItem(TEXT.check_date());
		menu.add(menuItem);

	}
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
}
